@@ -4,7 +4,7 @@
 # @FileName: __init__.py.py
 # @Company ：http://www.iqi-inc.com/
 
-from AiDragonfly.aiqi_main import start, Bluetooth_Data_Send
+from AiDragonfly.aiqi_main import start, Bluetooth_Data_Send,User_Receive_Callback_Register
 
 import AiDragonfly.aiqi_model.mesh.meshModule as Mesh
 
