@@ -1,7 +1,6 @@
 import sys
 
-Onebot_Dev_Name_Items = ['Onebot', 'Mibot', 'Mi_Builder_C1B', 'Onebot_Edu_01B', "OneBot_XL_M",
-                         "OneBot_St_M", "OneBot_LED", "OneBot_BL_M"]
+Onebot_Dev_Name_Items = ["OneBot_XL_M","OneBot_St_M", "OneBot_LED", "OneBot_BL_M"]
 Onebot_Dev_MeshName_Items = ["OneBot_XL_M", "OneBot_St_M", "OneBot_LED", "OneBot_BL_M"]
 Onebot_Dev_BleName_Items = ['Onebot', 'Mibot', 'Mi_Builder_C1B', 'Onebot_Edu_01B']
 
