@@ -24,9 +24,10 @@ def _read_local_json(name):
 
     if not os.path.isfile(json_path):
         print('file not exist,create new file')
-        file = open(json_path, 'w')
-        file.write('')
-        file.close()
+        _write_local_json('')
+        # file = open(json_path, 'w')
+        # file.write('')
+        # file.close()
         return None
     file = open(json_path)
     json_class = None
@@ -34,7 +35,7 @@ def _read_local_json(name):
         json_class = json.load(file)
         # print(json_class)
     except:
-        print('json load except')
+        # print('json load except')
         file = open(json_path, 'w')
         file.write('')
     file.close()
@@ -60,6 +61,8 @@ def Save_Local_Onebot_Device(dev_buff):
 def Read_Local_Onebot_Device():
     result = []
     read_buf = _read_local_json(save_json_name)
+    if read_buf == None:
+        return result
     # print('Read_Local_Onebot_Device:'+json.dumps(read_buf))
     for item in read_buf:
         dev = aiqi_bluetooth_dev_mes_class()
