@@ -37,6 +37,7 @@ mesh_control_flag = 0
 mesh_mode_flag = 0
 
 mesh_config_ack = False
+Main_Config_Stats = False
 
 __onebot_login = _mesh_login_class()
 __aiqi_adapter = aiqi_bluetooth.Aiqi_Bluetooth_Class()
@@ -50,6 +51,9 @@ def _protocol_analysis(num, data):  # 数据接收分析函数，根据报文协
     length = num
     _receive_message = data
     # Aiqi_Print_HEX(data)
+    if Main_Config_Stats is True:
+        if User_Reciver_Handle != None:
+            User_Reciver_Handle(num, data)
     if length > 3:  # 接收到的数据个数 小于三个 则抛弃
         if _receive_message[0] == 0x55:  # 红蓝主控的报文分析 0x55是红蓝主控协议的报头
             buf = _receive_message
@@ -422,7 +426,9 @@ onebot login
 
 
 async def __onebot_login_process():
-    global __wait_char_stats
+    global __wait_char_stats,Main_Config_Stats
+
+    Main_Config_Stats = False
     try:
         print("Waiting for connection.... If there is no connection within 8 seconds, the program will exit due to timeout")
         __wait_char_stats = True
@@ -492,6 +498,7 @@ async def __onebot_login_process():
     else:
         print('Device type does not exist:', __dev_type)
         sys.exit()
+    Main_Config_Stats = True
     print("running...")
 
 
@@ -521,6 +528,11 @@ async def sendDate(data):
 
 
 User_Disconnect_Handle = None
+User_Reciver_Handle = None
+
+def User_Receive_Callback_Register(callback):
+    global User_Reciver_Handle
+    User_Reciver_Handle = callback
 
 
 def _disconnect_callback(res):
